@@ -55,6 +55,7 @@ struct _EvSidebarAnnotationsPrivate {
 	GtkWidget   *tree_view;
 	GtkWidget   *palette;
 	GtkToolItem *annot_text_item;
+	GtkToolItem *annot_highlight_item;
 
 	EvJob       *job;
 	guint        selection_changed_id;
@@ -164,8 +165,8 @@ ev_sidebar_annotations_add_annots_list (EvSidebarAnnotations *ev_annots)
 }
 
 static void
-ev_sidebar_annotations_text_annot_button_toggled (GtkToggleToolButton  *toolbutton,
-						  EvSidebarAnnotations *sidebar_annots)
+ev_sidebar_annotations_annot_button_toggled (GtkToggleToolButton  *toolbutton,
+					     EvSidebarAnnotations *sidebar_annots)
 {
 	EvAnnotationType annot_type;
 
@@ -174,10 +175,14 @@ ev_sidebar_annotations_text_annot_button_toggled (GtkToggleToolButton  *toolbutt
 		return;
 	}
 
-	if (GTK_TOOL_ITEM (toolbutton) == sidebar_annots->priv->annot_text_item)
+	if (GTK_TOOL_ITEM (toolbutton) == sidebar_annots->priv->annot_text_item) {
+		gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (sidebar_annots->priv->annot_highlight_item), FALSE);
 		annot_type = EV_ANNOTATION_TYPE_TEXT;
-	else
-		annot_type = EV_ANNOTATION_TYPE_UNKNOWN;
+	} else if (GTK_TOOL_ITEM (toolbutton) == sidebar_annots->priv->annot_highlight_item) {
+		gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (sidebar_annots->priv->annot_text_item), FALSE);
+		annot_type = EV_ANNOTATION_TYPE_TEXT_MARKUP;
+	} else
+                g_assert_not_reached ();
 
 	g_signal_emit (sidebar_annots, signals[BEGIN_ANNOT_ADD], 0, annot_type);
 }
@@ -208,7 +213,19 @@ ev_sidebar_annotations_add_annots_palette (EvSidebarAnnotations *ev_annots)
 	gtk_widget_set_tooltip_text (GTK_WIDGET (item), _("Add text annotation"));
 	ev_annots->priv->annot_text_item = item;
 	g_signal_connect (item, "toggled",
-			  G_CALLBACK (ev_sidebar_annotations_text_annot_button_toggled),
+			  G_CALLBACK (ev_sidebar_annotations_annot_button_toggled),
+			  ev_annots);
+	gtk_tool_item_group_insert (GTK_TOOL_ITEM_GROUP (group), item, -1);
+	gtk_widget_show (GTK_WIDGET (item));
+
+	/* FIXME: use a better icon than INDEX */
+	item = gtk_toggle_tool_button_new ();
+	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), GTK_STOCK_INDEX);
+	gtk_tool_button_set_label (GTK_TOOL_BUTTON (item), _("Highlight"));
+	gtk_widget_set_tooltip_text (GTK_WIDGET (item), _("Add highlight annotation"));
+	ev_annots->priv->annot_highlight_item = item;
+	g_signal_connect (item, "toggled",
+			  G_CALLBACK (ev_sidebar_annotations_annot_button_toggled),
 			  ev_annots);
 	gtk_tool_item_group_insert (GTK_TOOL_ITEM_GROUP (group), item, -1);
 	gtk_widget_show (GTK_WIDGET (item));
@@ -285,9 +302,9 @@ ev_sidebar_annotations_class_init (EvSidebarAnnotationsClass *klass)
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 			      G_STRUCT_OFFSET (EvSidebarAnnotationsClass, begin_annot_add),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__ENUM,
-			      G_TYPE_NONE, 1,
-			      EV_TYPE_ANNOTATION_TYPE);
+                              g_cclosure_marshal_VOID__ENUM,
+                              G_TYPE_NONE, 1,
+                              EV_TYPE_ANNOTATION_TYPE);
 	signals[ANNOT_ADD_CANCELLED] =
 		g_signal_new ("annot-add-cancelled",
 			      G_TYPE_FROM_CLASS (g_object_class),
@@ -313,14 +330,31 @@ ev_sidebar_annotations_annot_added (EvSidebarAnnotations *sidebar_annots,
 {
 	GtkToggleToolButton *toolbutton;
 
-	if (EV_IS_ANNOTATION_TEXT (annot)) {
-		toolbutton = GTK_TOGGLE_TOOL_BUTTON (sidebar_annots->priv->annot_text_item);
+	if (EV_IS_ANNOTATION (annot)) {
+		switch (ev_annotation_get_annotation_type (annot)) {
+			case EV_ANNOTATION_TYPE_TEXT:
+				toolbutton = GTK_TOGGLE_TOOL_BUTTON (sidebar_annots->priv->annot_text_item);
+				break;
+			case EV_ANNOTATION_TYPE_TEXT_MARKUP:
+				switch (ev_annotation_text_markup_get_markup_type (EV_ANNOTATION_TEXT_MARKUP (annot))) {
+					case EV_ANNOTATION_TEXT_MARKUP_HIGHLIGHT: {
+						toolbutton = GTK_TOGGLE_TOOL_BUTTON (sidebar_annots->priv->annot_highlight_item);
+						break;
+					}
+					default:
+						g_assert_not_reached ();
+				}
+				break;
+			default:
+				g_assert_not_reached ();
+		}
+
 		g_signal_handlers_block_by_func (toolbutton,
-						 ev_sidebar_annotations_text_annot_button_toggled,
+						 ev_sidebar_annotations_annot_button_toggled,
 						 sidebar_annots);
 		gtk_toggle_tool_button_set_active (toolbutton, FALSE);
 		g_signal_handlers_unblock_by_func (toolbutton,
-						   ev_sidebar_annotations_text_annot_button_toggled,
+						   ev_sidebar_annotations_annot_button_toggled,
 						   sidebar_annots);
 	}
 
@@ -364,6 +398,7 @@ job_finished_callback (EvJobAnnots          *job,
         GdkPixbuf *highlight_icon = NULL;
         GdkPixbuf *strike_out_icon = NULL;
         GdkPixbuf *underline_icon = NULL;
+        GdkPixbuf *squiggly_icon = NULL;
 
 	priv = sidebar_annots->priv;
 
@@ -474,6 +509,14 @@ job_finished_callback (EvJobAnnots          *job,
                                         }
                                         pixbuf = underline_icon;
                                         break;
+                                case EV_ANNOTATION_TEXT_MARKUP_SQUIGGLY:
+                                        if (!squiggly_icon) {
+                                                squiggly_icon = gtk_widget_render_icon_pixbuf (priv->tree_view,
+                                                                                               GTK_STOCK_UNDERLINE,
+                                                                                               GTK_ICON_SIZE_BUTTON);
+                                        }
+                                        pixbuf = squiggly_icon;
+                                        break;
                                 }
                         }
 
@@ -505,6 +548,8 @@ job_finished_callback (EvJobAnnots          *job,
                 g_object_unref (strike_out_icon);
         if (underline_icon)
                 g_object_unref (underline_icon);
+        if (squiggly_icon)
+                g_object_unref (squiggly_icon);
 
 	g_object_unref (job);
 	priv->job = NULL;
